#
# spec file for package jq
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           jq
Version:        1.5
Release:        7.4
Summary:        A lightweight and flexible command-line JSON processor
License:        MIT and CC-BY-3.0
Group:          Productivity/Text/Utilities
Url:            http://stedolan.github.io/jq/
Source:         https://github.com/stedolan/jq/releases/download/jq-%{version}/jq-%{version}.tar.gz
Patch1:         CVE-2015-8863.patch
BuildRequires:  autoconf
BuildRequires:  chrpath
BuildRequires:  coreutils
BuildRequires:  make
BuildRequires:  oniguruma-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A lightweight and flexible command-line JSON processor. jq is like sed for
JSON data – you can use it to slice and filter and map and transform
structured data with the same ease that sed, awk, grep and friends let
you play with text.

%package -n libjq1
Summary:        Library for a lightweight and flexible command-line JSON processor
Group:          System/Libraries

%description -n libjq1
Library for a lightweight and flexible command-line JSON processor.

%package -n libjq-devel
Summary:        Development files for jq
Group:          Development/Languages/C and C++
Requires:       libjq1 = %{version}

%description -n libjq-devel
Development files (headers and libraries for jq).

%prep
%setup -q
%patch1 -p1

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install

# RPATH contains the builddir yucks!
chrpath -d %{buildroot}%{_bindir}/jq

# No static stuff
rm %{buildroot}%{_libdir}/libjq.la

# we install the documentation in a separate location using the doc macro
rm -rf %{buildroot}%{_datadir}/doc/%{name}

%post -n libjq1 -p /sbin/ldconfig

%postun -n libjq1 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING NEWS README README.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1.gz

%files -n libjq1
%defattr(-,root,root)
%{_libdir}/libjq.so.1*

%files -n libjq-devel
%defattr(-,root,root)
%{_includedir}/jq.h
%{_includedir}/jv.h
%{_libdir}/libjq.so

%changelog
* Mon Apr 25 2016 idonmez@suse.com
- Add CVE-2015-8863.patch to fix a heap overflow bsc#976992
* Tue Aug 18 2015 idonmez@suse.com
- Update to version 1.5
  * Regexp support
  * A proper module system
  * Destructuring syntax
  * Math functions
  * An online streaming parser
  * Minimal I/O builtins (inputs, debug)
  * try/catch for catching and handling errors
  * Tail call optimization
  * Datetime functions
  * Performance enhancements
- Add oniguruma-devel BuildRequires for regexp support
* Fri Jun 27 2014 idonmez@suse.com
- Don't package static libs
- Fix rpath on the main binary
* Sun Jun 15 2014 prusnak@opensuse.org
- Updated to 1.4
  + New command line arguments
  * jq --arg-file variable file
  * jq --unbuffered
  * jq -e / --exit-status (set exit status based on outputs)
  * jq -S / --sort-keys (now jq no longer sorts object keys by
    default
  + Syntax changes
  * .. -> like // in XPath (recursive traversal)
  * question mark (e.g., .a?) to suppress errors
  * ."foo" syntax (equivalent to .["foo"])
  * better error handling for .foo
  * added %% operator (modulo)
  * allow negation without requiring extra parenthesis
  * more function arguments (up to six)
  + New filters
  * any, all
  * iterables, arrays, objects, scalars, nulls, booleans,
    numbers, strings, values
  + New string built-ins
  * split
  * join (join an array of strings with a given separator string)
  * ltrimstr, rtrimstr
  * startswith, endswith
  * explode, implode
  * fromjson, tojson
  * index, rindex, indices
  + New math functions
  * floor, sqrt, cbrt, etc.
  + Addition of libjq, a C API interface to jq's JSON representation
    and for running jq programs from C applications.
* Thu Oct 17 2013 cdenicolo@suse.com
- license update: MIT and CC-BY-3.0
  documentation is licensed under CC-BY-3.0
* Tue Oct  1 2013 robert.munteanu@gmail.com
- Initial packaging of version 1.3
